@@ -19,12 +19,16 @@ class BaseView(object):
         self.model.add_notify(self)
         if self.fields == ():
             self.fields = [x for x in self.model.get_fields()]
-            self.fields.remove(self.exclude_fields)
+
 
     def refresh(self):
         """docstring for dataChanged"""
         pass
 
+    def clean(self):
+        """Cleans temporary models of view"""
+        raise NotImplementedError
+
 
     def save(self):
         """Saves models changes in view"""
